-- 
-- e[u̍\ `anywheressl`
-- 

CREATE TABLE `anywheressl` (
  `session_id` varchar(32) NOT NULL default '',
  `session_data` text NOT NULL,
  `limit_time` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`session_id`),
  KEY `limit_time` (`limit_time`)
) TYPE=MyISAM;


-- --------------------------------------------------------

-- 
-- e[u̍\ `anywheressl_configs`
-- 

CREATE TABLE `anywheressl_configs` (
  `conf_id` smallint(5) unsigned NOT NULL auto_increment,
  `conf_name` varchar(30) NOT NULL default '',
  `conf_value` varchar(60) NOT NULL default '',
  PRIMARY KEY  (`conf_id`),
  KEY `conf_name` (`conf_name`)
) TYPE=MyISAM ;


-- --------------------------------------------------------

-- 
-- e[u̍\ `anywheressl_enforce`
-- 

CREATE TABLE `anywheressl_enforce` (
  `fid` smallint(5) unsigned NOT NULL auto_increment,
  `mid` smallint(5) unsigned NOT NULL default '0',
  `script_filename` varchar(30) NOT NULL default '',
  PRIMARY KEY  (`fid`),
  KEY `mid` (`mid`,`script_filename`)
) TYPE=MyISAM ;
